pub struct RefreshMetadata {
pub method: Method,
pub uri: Uri,
pub headers: Vec<(String, Vec<u8>)>,
}Expand description
Metadata needed to reconstruct a request for auto-refresh.
Fields
method: Methoduri: Uriheaders: Vec<(String, Vec<u8>)>Implementations
Sourceimpl RefreshMetadata
impl RefreshMetadata
Sourcepub fn from_request<B>(req: &Request<B>) -> Self
pub fn from_request<B>(req: &Request<B>) -> Self
Creates new refresh metadata from a request.
Sourcepub fn from_request_with_headers<B>(
req: &Request<B>,
header_names: &[String],
) -> Self
pub fn from_request_with_headers<B>( req: &Request<B>, header_names: &[String], ) -> Self
Creates new refresh metadata with specific headers to store.
Sourcepub fn try_into_request(&self) -> Option<Request<()>>
pub fn try_into_request(&self) -> Option<Request<()>>
Attempts to reconstruct a request from this metadata.
Returns None if the request cannot be reconstructed (e.g., invalid URI).