RefreshCallback

Trait RefreshCallback 

pub trait RefreshCallback: Send + Sync {
    // Required method
    fn refresh(&self, key: String, metadata: RefreshMetadata) -> RefreshFuture;
}
Callback trait for triggering refresh operations.

This trait is implemented by the cache layer to actually perform the refresh.

Required Methods

fn refresh(&self, key: String, metadata: RefreshMetadata) -> RefreshFuture

Triggers a refresh for the given key and metadata.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors